/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1

Rectangle{
    id: root
    height: columnA.height + units.gu(4)
    color: screenMA.pressed && !isLastItem ? "#FFDB88" : formulaView.color
    transformOrigin: Item.Bottom

    signal useAnswer(string answerToUse, string formulaData)

    Text {
        width: parent.width
        visible: isLastItem && index && formulaView.positionedAtEnd > 0
        clip: true
        text: "^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ^"
        color: "#C0C0C0"
    }


    Column {
        id: columnA
        spacing: units.gu(2)
        width: parent.width - units.gu(8)
        anchors.centerIn: parent

        Label {
            id: formulaLabel
            width: parent.width
            height: units.gu(13)
            font.pixelSize: units.gu(4)
            fontSizeMode: Text.Fit
            wrapMode: Text.WordWrap
            text: formula
        }

        Label {
            id: answerLabel
            width: parent.width
            height: units.gu(5)
            clip: true
            font.pixelSize: units.gu(4)
            fontSizeMode: Text.Fit
            color: "#dd4814"
            text: '= ' + answer
        }
    }

    Divider {
        visible: !isLastItem
        width: parent.width
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }
    }

    MouseArea {
        id: screenMA
        anchors.fill: parent
        onClicked: {
            if (answer.indexOf('error') === -1)
                root.useAnswer(answer, formula_data)
        }
    }
}
