/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1

Item {
    width: parent.width
    height: grid.height+units.gu(4)

    Grid {
        id: grid
        columns: Math.floor(parent.width / units.gu(46))

        anchors{
            top: parent.top
            topMargin: units.gu(2)
            horizontalCenter: parent.horizontalCenter
        }
        spacing: units.gu(2)
        Grid{
            columns:4
            spacing: units.gu(2)

            KeyboardButton {
                text: "("
                onClicked: formulaPush('(', '(', 'group')
            }

            KeyboardButton {
                text: ")"
                onClicked: formulaPush(')', ')', 'group')
            }

            KeyboardButton {
                text: "C"
                onClicked: {
                    formulaView.addCurrentToMemory();
                    formulaReset();
                }
            }

            KeyboardButton {
                text: "M"
                onClicked: {
                    formulaView.addCurrentToMemory();
                }
            }

            KeyboardButton {
                text: "7"
                onClicked: formulaPush('7', '7', 'number')
            }

            KeyboardButton {
                text: "8"
                onClicked: formulaPush('8', '8', 'number')
            }

            KeyboardButton {
                text: "9"
                onClicked: formulaPush('9', '9', 'number')
            }

            KeyboardButton {
                text: "÷"
                onClicked: formulaPush('÷', '/', 'operation')
            }

            KeyboardButton {
                text: "4"
                onClicked: formulaPush('4', '4', 'number')
            }

            KeyboardButton {
                text: "5"
                onClicked: formulaPush('5', '5', 'number')
            }

            KeyboardButton {
                text: "6"
                onClicked: formulaPush('6', '6', 'number')
            }

            KeyboardButton {
                text: "×"
                onClicked: formulaPush('×', '*', 'operation')
            }

            KeyboardButton {
                text: "1"
                onClicked: formulaPush('1', '1', 'number')
            }

            KeyboardButton {
                text: "2"
                onClicked: formulaPush('2', '2', 'number')
            }

            KeyboardButton {
                text: "3"
                onClicked: formulaPush('3', '3', 'number')
            }

            KeyboardButton {
                text: "+"
                onClicked: formulaPush('+', '+', 'operation')
            }

            KeyboardButton {
                text: "0"
                onClicked: formulaPush('0', '0', 'number')
            }

            KeyboardButton {
                text: "."
                onClicked: formulaPush('.', '.', 'real')
            }

            KeyboardButton {
                text: "←"
                onClicked: formulaPop()
                onPressAndHold: formulaReset()
            }

            KeyboardButton {
                text: "−"
                onClicked: formulaPush('−', '-', 'operation')
            }

        }

        Grid{
            spacing: units.gu(2)

            KeyboardButton {
                text: "sin"
                onClicked: formulaPush('sin', 'sin', 'function')
            }

            KeyboardButton {
                text: "cos"
                onClicked: formulaPush('cos', 'cos', 'function')
            }

            KeyboardButton {
                text: "tan"
                onClicked: formulaPush('tan', 'tan', 'function')
            }

            KeyboardButton {
                text: angularUnit
                onClicked: {
                    if (angularUnit === 'RAD') {
                        angularUnit = 'DEG';
                    }
                    else if (angularUnit === 'DEG') {
                        angularUnit = 'GRAD';
                    }
                    else if (angularUnit === 'GRAD') {
                        angularUnit = 'RAD'
                    }
                    calculate();
                }
            }

            KeyboardButton {
                text: "asin"
                onClicked: formulaPush('asin', 'asin', 'function')
            }

            KeyboardButton {
                text: "acos"
                onClicked: formulaPush('acos', 'acos', 'function')
            }

            KeyboardButton {
                text: "atan"
                onClicked: formulaPush('atan', 'atan', 'function')
            }


            KeyboardButton {
                text: "ln"
                onClicked: formulaPush('ln', 'ln', 'function')
            }

            KeyboardButton {
                text: "√"
                onClicked: formulaPush('√', '√', 'function')
            }

            KeyboardButton {
                text: "π"
                onClicked: formulaPush('π', 'π', 'const')
            }

            KeyboardButton {
                text: "e"
                onClicked: formulaPush('e', 'E', 'const')
            }

            KeyboardButton {
                text: "log"
                onClicked: formulaPush('log', 'log', 'function')
            }

            KeyboardButton {
                text: "%"
                onClicked: formulaPush('%', '%', 'operation')
            }

            KeyboardButton {
                text: "!"
                onClicked: formulaPush('!', '!', 'operation')
            }

            KeyboardButton {
                text: "^"
                onClicked: formulaPush('^', '^', 'operation')
            }
        }

    }
}
