/*
 * Copyright 2013-2014 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.Themes.Ambiance 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

ListItem.Standard {
    id: root
    height: _content.height + divider.height
    transformOrigin: Item.Bottom

    removable: !isLastItem
    confirmRemoval: true 
    onItemRemoved: root.removeItem()
    showDivider: false

    property var ops
    property bool newCalculation: false
    signal useAnswer(string answerToUse, string formulaData)
    signal labelTextUpdated(int idx, string newText)
    signal mainLabelUpdated(int idx, string newText)
    signal removeItem()

    Item {
        id: _content
        width: parent.width
        height: inputs.height+units.gu(2)

        Column {
            id: inputs
            anchors.top: parent.top
            anchors.topMargin: units.gu(2)
            width: parent.width - units.gu(3)
            anchors.centerIn: parent

            //Edit Button icon and time in parent line
            Item {
                id: row
                height: units.gu(4)
                width: parent.width
                visible: !isLastItem || newCalculation && formulaView.headerItem.state !== ""
                Item {
                    id: editIcon
                    objectName: "editIcon"
                    height: parent.height
                    width: units.gu(3)
                    Image {
                        anchors.verticalCenter: parent.verticalCenter
                        source: Qt.resolvedUrl("images/edit.png")
                    }

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            if (labelVisible) {
                                title.focus = false;
                                labelVisible = false;
                            }
                            else {
                                title.focus = true;
                                title.forceActiveFocus();
                                labelVisible = true
                            }
                        }
                        propagateComposedEvents: true
                    }
                }
                Item {
                    width: parent.width / 2
                    height: parent.height

                    TextField {
                        id: title
                        objectName: "title"
                        width: parent.width
                        anchors.verticalCenter: parent.verticalCenter
                        x: units.gu(3)
                        // removes ubuntu shape
                        style: TextFieldStyle {
                            background: Item {}
                        }
                        text: mainLabel
                        color: "#FEFEFE"
                        onTextChanged: { root.mainLabelUpdated(index, text) }
                        hasClearButton: false
                        font.pixelSize: FontUtils.sizeToPixels("medium")

                        maximumLength: 20;

                        onActiveFocusChanged: {
                            if (title.activeFocus) {
                                labelVisible = true;
                            }
                            else
                                saveMainLabel(mainLabel);
                        }
                    }

                    Image {
                        visible: labelVisible
                        anchors.bottom: parent.bottom
                        x: units.gu(3)
                        source: Qt.resolvedUrl("images/dot.png")
                        fillMode: Image.Tile
                        width: parent.width - units.gu(1.5)
                        height: units.gu(0.5)
                    }
                }

                InverseMouseArea {
                    onClicked: {
                        title.focus = false;
                        mouse.accepted = false;
                        labelVisible = false;
                    }
                    anchors.fill: parent;
                    visible: title.activeFocus;
                    propagateComposedEvents: true
                }

                Label {
                    id: dateLabel
                    height: parent.height
                    anchors.right: parent.right
                    color: "#9094AA"
                    text: dateText
                    font.capitalization: Font.AllUppercase

                    MouseArea {
                        onClicked: {
                            title.focus = false;
                            mouse.accepted = false;
                            labelVisible = false;
                        }
                        anchors.fill: parent;
                        visible: title.activeFocus;
                        propagateComposedEvents: true
                    }
                }
            }

            Repeater{
                id: repeater
                model: ops
                Column{
                    width: row.width
                    spacing: units.gu(0.5)
                    Rectangle{
                        visible: (_operation == '=')
                        height: units.gu(0.1)
                        width: formulaLabel.operationsWidth
                        anchors.right: parent.right
                        color: "#FEFEFE"
                    }
                    Item {
                        visible: (_operation == '=')
                        height: units.gu(0.9)
                        width: formulaLabel.operationsWidth
                    }
                    CalcLabel {
                        objectName: _operation == "=" ? "result" : "operand" + index
                        id: formulaLabel
                        labelText: _text
                        numbers: _number
                        operation: _operation == "=" ? "" : _operation
                        numbersHeight: FontUtils.sizeToPixels("x-large")
                        isLast: (isLastItem && index === repeater.model.count-1)

                        onLabelTextChanged: {
                            root.labelTextUpdated(index, labelText)
                        }

                        onNumbersChanged: {
                            newCalculation = true
                        }

                        onOperationChanged: {
                            newCalculation = true
                        }

                        /*
                         * Fix for bug 1207687
                         * See https://bugs.launchpad.net/ubuntu-calculator-app/+bug/1207687/comments/7
                         * onPressed has to be added to all parts of calc that on first click don't swipe
                         */
                        MouseArea {
                            onPressed: {}
                            propagateComposedEvents: true
                        }
                    }
                }
            }

            /* Empty space */
            Item {
                height: units.gu(3)
                width: parent.width
            }
        }

        MouseArea {
            anchors.fill: parent
            propagateComposedEvents: true

            onPressed: {
                mouse.accepted = false
            }
        }
    }

    ListItem.Divider {
        id: divider
        visible: !isLastItem
        width: parent.width
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }
    }
}
