/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../engine.js" as CALC

TestCase{
    name: "Basic math"

    function test_additions_data(){
        return [
                    {operation: "5+2", expected: 7},
                    {operation: "5+2.3", expected: 7.3},
                    {operation: "5.3+2", expected: 7.3},
                    {operation: "5.3+2.3", expected: 7.6}
                ]
    }

    function test_subtractions_data(){
        return [
                    {operation: "3-2", expected: 1},
                    {operation: "3-2.1", expected: 0.9},
                    {operation: "3.2-1", expected: 2.2},
                    {operation: "3.2-1.3", expected: 1.9}
                ]
    }

    function test_negative_data(){
        return [
                    {operation: "3+-2", expected: 1},
                    {operation: "-3.3+2", expected: -1.3},
                    {operation: "-2-2", expected: -4}
                ]
    }

    function test_multiplications_data(){
        return [
                    {operation: "5*2", expected: 10},
                    {operation: "5*2.2", expected: 11},
                    {operation: "5.31*7", expected: 37.17}
                ]
    }

    function test_divisions_data(){
        return [
                    {operation: "4/2", expected: 2},
                    {operation: "1/3", expected: 0.3333333333333},
                    {operation: "3.5/2", expected: 1.75},
                    {operation: "2.5/3", expected: 0.8333333333333}
                ]
    }

    function test_additions(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_subtractions(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_negative(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_multiplications(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_divisions(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }
}
