/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../engine.js" as CALC

TestCase{
    name: "Exceptions"

    function test_division_by_zero_data(){
        return [
                    {operation: "3/0", expected: Number.POSITIVE_INFINITY},
                    {operation: "5%0", expected: "division by zero error"}
                ]
    }

    function test_syntax_errors_data(){
        return [
                    {operation: "3/*1", expected: "syntax error"},
                    {operation: "sin3", expected: "syntax error"},
                    {operation: "hello", expected: "syntax error"},
                    {operation: "Eπc", expected: "syntax error"}
                ]
    }

    function test_parenthesis_errors_data(){
        return [
                    {operation: "1(3-2", expected: "unmatched )"},
                    {operation: "(2-1(+3)))", expected: "unmatched ("}
                ]
    }

    function calculate(operation){
        var result = 0;
        try{
            result = CALC.parse(operation);
        } catch(exception) {
            switch(true){
            case exception instanceof CALC.DivisionByZeroError :
                return "division by zero error";
            case exception instanceof CALC.ParenthesisError :
                return "unmatched %1".arg(exception.missing);
            case exception instanceof SyntaxError :
                return "syntax error"
            default:
                return exception.message;
            }
        }
        return result;
    }

    function test_division_by_zero(data){
        compare(calculate(data.operation), data.expected, data.operation);
    }

    function test_syntax_errors(data){
        compare(calculate(data.operation), data.expected, data.operation);
    }

    function test_parenthesis_errors(data){
        compare(calculate(data.operation), data.expected, data.operation);
    }

}
