/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../engine.js" as CALC

TestCase{
    name: "Get Formula Texts"

    function test_brackets_data(){
        return [
                    {
                    operation: "bracket after number",
                    prev: {engine: '5', type: 'number'},
                    visual: "(", engine: "(", type: 'group', brackets_count: 0,
                    expected: [' ( ', '(', 'group', 1]
                    },
                    {
                    operation: "bracket after real",
                    prev: {engine: '5', type: 'real'},
                    visual: "(", engine: "(", type: 'group', brackets_count: 0,
                    expected: [' ( ', '(', 'group', 1]
                    },
                    {
                    operation: "bracket after const",
                    prev: {engine: 'e', type: 'const'},
                    visual: "(", engine: "(", type: 'group', brackets_count: 0,
                    expected: [' ( ', '(', 'group', 1]
                    },
                    {
                    operation: "bracket after operation",
                    prev: {engine: '*', type: 'operation'},
                    visual: "(", engine: "(", type: 'group', brackets_count: 0,
                    expected: [' ( ', '(', 'group', 1]
                    },
                    {
                    operation: "bracket after operation",
                    prev: {engine: '*', type: 'operation'},
                    visual: "(", engine: "(", type: 'group', brackets_count: 0,
                    expected: [' ( ', '(', 'group', 1]
                    },
                    {
                    operation: "closing bracket after number",
                    prev: {engine: '5', type: 'number'},
                    visual: ")", engine: ")", type: 'group', brackets_count: 1,
                    expected: [' ) ', ')', 'group', 0]
                    },
                    {
                    operation: "closing bracket after operation",
                    prev: {engine: '*', type: 'operation'},
                    visual: ")", engine: ")", type: 'group', brackets_count: 1,
                    expected: [null, null, 'group', 1]
                    },
                    {
                    operation: "closing bracket after function",
                    prev: {engine: 'sin(', type: 'function'},
                    visual: ")", engine: ")", type: 'group', brackets_count: 1,
                    expected: [null, null, 'group', 1]
                    },
               ]
    }

    function test_numbers_and_consts_data(){
        return [
                    {
                    operation: "number after number",
                    prev: {engine: '5', type: 'number'},
                    visual: "3", engine: "3", type: 'number', brackets_count: 0,
                    expected: ['3', '3', 'number', 0]
                    },
                    {
                    operation: "number after constant",
                    prev: {engine: 'e', type: 'const'},
                    visual: "3", engine: "3", type: 'number', brackets_count: 0,
                    expected: ['3', '3', 'number', 0]
                    },
                    {
                    operation: "number after real",
                    prev: {engine: '.', type: 'real'},
                    visual: "3", engine: "3", type: 'number', brackets_count: 0,
                    expected: ['3', '3', 'real', 0]
                    },
                    {
                    operation: "real after number",
                    prev: {engine: '5', type: 'number'},
                    visual: ".", engine: ".", type: 'real', brackets_count: 0,
                    expected: ['.', '.', 'real', 0]
                    },
                    {
                    operation: "real after const",
                    prev: {engine: 'e', type: 'const'},
                    visual: ".", engine: ".", type: 'real', brackets_count: 0,
                    expected: ['.', '.', 'real', 0]
                    },
                    {
                    operation: "real after real",
                    prev: {engine: '.', type: 'real'},
                    visual: ".", engine: ".", type: 'real', brackets_count: 0,
                    expected: [null, null, 'real', 0]
                    },
                    {
                    operation: "const after number",
                    prev: {engine: '5', type: 'number'},
                    visual: "e", engine: "e", type: 'const', brackets_count: 0,
                    expected: ['e', 'e', 'const', 0]
                    },
                    {
                    operation: "const after real",
                    prev: {engine: '5', type: 'real'},
                    visual: "e", engine: "e", type: 'const', brackets_count: 0,
                    expected: ['e', 'e', 'const', 0]
                    },
                    {
                    operation: "const after const",
                    prev: {engine: 'e', type: 'const'},
                    visual: "e", engine: "e", type: 'const', brackets_count: 0,
                    expected: ['e', 'e', 'const', 0]
                    },
                    {
                    operation: "const after function",
                    prev: {engine: 'sin(', type: 'function'},
                    visual: "e", engine: "e", type: 'const', brackets_count: 0,
                    expected: ['e', 'e', 'const', 0]
                    },
               ]
    }

    function test_operations_data(){
        return [
                    {
                    operation: "operation after number",
                    prev: {engine: '5', type: 'number'},
                    visual: "-", engine: "-", type: 'operation', brackets_count: 0,
                    expected: [' - ', '-', 'operation', 0]
                    },
                    {
                    operation: "operation (multiplication) after number",
                    prev: {engine: '5', type: 'number'},
                    visual: "*", engine: "*", type: 'operation', brackets_count: 0,
                    expected: [' * ', '*', 'operation', 0]
                    },
                    {
                    operation: "operation (multiplication) after real",
                    prev: {engine: '5', type: 'real'},
                    visual: "*", engine: "*", type: 'operation', brackets_count: 0,
                    expected: [' * ', '*', 'operation', 0]
                    },
                    {
                    operation: "operation (multiplication) after const",
                    prev: {engine: 'e', type: 'const'},
                    visual: "*", engine: "*", type: 'operation', brackets_count: 0,
                    expected: [' * ', '*', 'operation', 0]
                    },
                    {
                    operation: "operation (multiplication) after closing bracket",
                    prev: {engine: ')', type: 'group'},
                    visual: "*", engine: "*", type: 'operation', brackets_count: 0,
                    expected: [' * ', '*', 'operation', 0]
                    },
                    {
                    operation: "operation (multiplication) after operation",
                    prev: {engine: '*', type: 'operation'},
                    visual: "*", engine: "*", type: 'operation', brackets_count: 0,
                    expected: [null, null, 'operation', 0]
                    },
                    {
                    operation: "operation (division) after operation",
                    prev: {engine: '*', type: 'operation'},
                    visual: "/", engine: "/", type: 'operation', brackets_count: 0,
                    expected: [null, null, 'operation', 0]
                    },
                    {
                    operation: "operation (division) after function",
                    prev: {engine: 'sin(', type: 'function'},
                    visual: "/", engine: "/", type: 'operation', brackets_count: 0,
                    expected: [null, null, 'operation', 0]
                    },
                    {
                    operation: "operation (multiplication) after opening bracket",
                    prev: {engine: '(', type: 'group'},
                    visual: "*", engine: "*", type: 'operation', brackets_count: 0,
                    expected: [null, null, 'operation', 0]
                    },
                    {
                    operation: "operation (factorial) after operation (minus)",
                    prev: {engine: '-', type: 'operation'},
                    visual: "!", engine: "!", type: 'operation', brackets_count: 0,
                    expected: [null, null, 'operation', 0]
                    },
                    {
                    operation: "operation (factorial) after operation (multiplication)",
                    prev: {engine: '*', type: 'operation'},
                    visual: "!", engine: "!", type: 'operation', brackets_count: 0,
                    expected: [null, null, 'operation', 0]
                    },
                    {
                    operation: "operation (factorial) after operation (factorial)",
                    prev: {engine: '!', type: 'operation'},
                    visual: "!", engine: "!", type: 'operation', brackets_count: 0,
                    expected: [' ! ', '!', 'operation', 0]
                    },
               ]
    }

    function test_functions_data(){
        return [
                    {
                    operation: "function after number",
                    prev: {engine: '5', type: 'number'},
                    visual: "sin", engine: "sin", type: 'function', brackets_count: 0,
                    expected: [' sin( ', 'sin(', 'function', 1]
                    },
                    {
                    operation: "function after real",
                    prev: {engine: '5', type: 'real'},
                    visual: "sin", engine: "sin", type: 'function', brackets_count: 0,
                    expected: [' sin( ', 'sin(', 'function', 1]
                    },
                    {
                    operation: "function after const",
                    prev: {engine: 'e', type: 'const'},
                    visual: "sin", engine: "sin", type: 'function', brackets_count: 0,
                    expected: [' sin( ', 'sin(', 'function', 1]
                    },
                    {
                    operation: "function after operation",
                    prev: {engine: '*', type: 'operation'},
                    visual: "sin", engine: "sin", type: 'function', brackets_count: 0,
                    expected: ['sin( ', 'sin(', 'function', 1]
                    },
                    {
                    operation: "function after function",
                    prev: {engine: 'sin(', type: 'function'},
                    visual: "sin", engine: "sin", type: 'function', brackets_count: 0,
                    expected: ['sin( ', 'sin(', 'function', 1]
                    },
               ]
    }

    function test_brackets(data) {
        compare(CALC.getFormulaTexts(data.prev, data.visual, data.engine, data.type, data.brackets_count),
                    data.expected,
                    data.operation);
    }

    function test_numbers_and_consts(data) {
        compare(CALC.getFormulaTexts(data.prev, data.visual, data.engine, data.type, data.brackets_count),
                    data.expected,
                    data.operation);
    }

    function test_operations(data) {
        compare(CALC.getFormulaTexts(data.prev, data.visual, data.engine, data.type, data.brackets_count),
                    data.expected,
                    data.operation);
    }

    function test_functions(data) {
        compare(CALC.getFormulaTexts(data.prev, data.visual, data.engine, data.type, data.brackets_count),
                    data.expected,
                    data.operation);
    }
}
