/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../engine.js" as CALC

TestCase{
    name: "Scientific math"

    function test_operations_precedence_data(){
        return [
                    {operation: "5+2-(3+4)", expected: 0},
                    {operation: "3*(2*(2+1))/2", expected: 9},
                    {operation: "(5.3+2)/(1.6*7.3)", expected: 0.625}
                ]
    }

    function test_constants_data(){
        return [
                    {operation: "π", expected: 3.141592653589793},
                    {operation: "E", expected: 2.718281828459045}
                ]
    }

    function test_exponentiation_data(){
        return [
                    {operation: "3^2", expected: 9},
                    {operation: "10^(-3)", expected: 0.001},
                    {operation: "(2^3)^4", expected: 4096}
                ]
    }

    function test_square_root_data(){
        return [
                    {operation: "√(4)", expected: 2},
                    {operation: "√(9)", expected: 3}
                ]
    }

    function test_logarithm_data(){
        return [
                    {operation: "ln(1)", expected: 0},
                    {operation: "ln(E^3)", expected: 3}
                ]
    }

    function test_trigonometrics_data(){
        return [
                    {operation: "sin(0)", expected: 0},
                    {operation: "RAD sin(π/2)", expected: 1},
                    {operation: "cos(π)", expected: -1},
                    {operation: "cos(π/2, %1)".arg(CALC.RAD), expected: 0},
                    {operation: "tan(0)", expected: 0},
                    {operation: "tan(π/4, %1)".arg(CALC.RAD), expected: 1}
                    //TODO: add tests for acsin, acos, atan and DEG and GRAD modes
                ]
    }

    function test_factorial_data(){
        return [
                    {operation: "4!", expected: 24},
                    {operation: "4!+2", expected: 26},
                    {operation: "3!*2", expected: 12}
                ]
    }

    function test_operations_precedence(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_constants(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_exponentiation(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_square_root(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_logarithm(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_trigonometrics(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }

    function test_factorial(data){
        compare(CALC.parse(data.operation), data.expected, data.operation);
    }
}
