/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../engine.js" as CALC

TestCase{
    name: "Engine smartness"

    function test_implicit_multiplications_data(){
        return [
                    {operation: "3(2)", expected: "3*(2)"},
                    {operation: "(3)2", expected: "(3)*2"},
                    {operation: "3E", expected: "3*E"},
                    {operation: "E3", expected: "E*3"},
                    {operation: "π(2)(2)", expected: "π*(2)*(2)"},
                    {operation: "Eπ", expected: "E*π"},
                    {operation: "2cos(3)", expected: "2*cos(3)"},
                    {operation: "πcos(3)", expected: "π*cos(3)"},
                    {operation: "Esin(2)", expected: "E*sin(2)"}
                ]
    }

    function test_spaced_formulas_data(){
        return [
                    {operation: "3 + 1", expected: "3+1"},
                    {operation: "3 ( 2 )", expected: "3*(2)"},
                    {operation: "1                +              1", expected: "1+1"},
                    {operation: " cos ( 3 )", expected: "cos(3)"}
                ]
    }

    function test_implicit_multiplications(data){
        compare(CALC.parse(data.operation), CALC.parse(data.expected), data.operation);
    }

    function test_spaced_formulas(data){
        compare(CALC.parse(data.operation), CALC.parse(data.expected), data.operation);
    }
}
